Verk v1.0.1 Verk.DeadSet
This module interacts with jobs in the dead set
Link to this section Summary
Functions
Adds a job to the dead set ordering by timestamp
Adds a job to the dead set ordering by timestamp, raising if there’s an error
Clears the dead set
Clears the dead set, raising if there’s an error
Counts how many jobs are inside the dead set
Counts how many jobs are inside the dead set, raising if there’s an error
Delete the job from the dead set
Delete the job from the dead set, raising if there’s an exception
Redis dead set key
List jobs from start to stop
List jobs from start to stop, raising if there’s an error
Link to this section Functions
add(%Verk.Job{args: term, class: term, enqueued_at: term, error_backtrace: term, error_message: term, failed_at: term, finished_at: term, jid: term, max_retry_count: term, original_json: term, queue: term, retried_at: term, retry_count: term}, integer, GenServer.server) ::
:ok |
{:error, Redix.Error.t}
Adds a job to the dead set ordering by timestamp
Optionally a redis connection can be specified
add!(%Verk.Job{args: term, class: term, enqueued_at: term, error_backtrace: term, error_message: term, failed_at: term, finished_at: term, jid: term, max_retry_count: term, original_json: term, queue: term, retried_at: term, retry_count: term}, integer, GenServer.server) :: nil
Adds a job to the dead set ordering by timestamp, raising if there’s an error
Optionally a redis connection can be specified
clear(GenServer.server) :: :ok | {:error, RuntimeError.t | Redix.Error.t}
Clears the dead set
Clears the dead set, raising if there’s an error
count(GenServer.Server) ::
{:ok, integer} |
{:error, Redix.Error.t}
Counts how many jobs are inside the dead set
Counts how many jobs are inside the dead set, raising if there’s an error
delete_job(%Verk.Job{args: term, class: term, enqueued_at: term, error_backtrace: term, error_message: term, failed_at: term, finished_at: term, jid: term, max_retry_count: term, original_json: term, queue: term, retried_at: term, retry_count: term} | String.t, GenServer.server) ::
:ok |
{:error, RuntimeError.t | Redix.Error.t}
Delete the job from the dead set
delete_job!(%Verk.Job{args: term, class: term, enqueued_at: term, error_backtrace: term, error_message: term, failed_at: term, finished_at: term, jid: term, max_retry_count: term, original_json: term, queue: term, retried_at: term, retry_count: term} | String.t, GenServer.server) :: nil
Delete the job from the dead set, raising if there’s an exception
Redis dead set key
range(integer, integer, GenServer.server) :: {:ok, [Verk.Job.T]} | {:error, Redix.Error.t}
List jobs from start to stop
range!(integer, integer, GenServer.server) :: [Verk.Job.T]
List jobs from start to stop, raising if there’s an error