Verk v0.9.7
Modules summary
| Verk | Verk is a job processing system that integrates well with Sidekiq jobs |
| Verk.DeadSet | This module interacts with jobs in the dead set |
| Verk.Events | |
| Verk.Events.JobFailed | |
| Verk.Events.JobFinished | |
| Verk.Events.JobStarted | |
| Verk.Job | |
| Verk.Log | |
| Verk.Queue | This module interacts with a queue |
| Verk.Queue.Supervisor | |
| Verk.QueueManager | QueueManager interacts with redis to dequeue jobs from the specified queue |
| Verk.QueueManager.State | |
| Verk.QueueStats | This process will update an :ets table with the following information per queue |
| Verk.RetrySet | This module interacts with jobs in the retry set |
| Verk.ScheduleManager | The ScheduleManager looks for jobs to be retried and accept jobs to scheduled to be retried |
| Verk.ScheduleManager.State | |
| Verk.Scripts | Provides helpers to load lua scripts into redis and calculate sha1 |
| Verk.SortedSet | This module interacts with the jobs on a sorted set |
| Verk.Supervisor | |
| Verk.Worker | Worker executes the job, messages the manager when it’s done and shutdowns |
| Verk.WorkersManager | A WorkersManager assign jobs to workers from a pool (handled by poolboy) monitoring the job |
| Verk.WorkersManager.State |